@@ -3,7 +3,7 @@
 #############################################################################
 ## 
 ##   Unit testing automation script
-##   Last updated on January 26, 2023
+##   Last updated on February 21, 2023
 ## 
 ##   This file is part of Logtalk <https://logtalk.org/>  
 ##   Copyright 1998-2023 Paulo Moura <pmoura@logtalk.org>
@@ -25,8 +25,10 @@
 
 # loosely based on a unit test automation script contributed by Parker Jones
 
+set -o pipefail
+
 print_version() {
-	echo "$(basename "$0") 11.0"
+	echo "$(basename "$0") 12.0"
 	exit 0
 }
 
@@ -56,7 +58,6 @@ fi
 
 # default argument values
 
-backend=""
 driver='tester'
 dot=""
 output='verbose'
@@ -154,11 +155,11 @@ run_testset() {
 		mode_prefix="% (debug) "
 	fi
 
-	if [ $tests_exit -eq 0 ] && [ "$output" == 'verbose' ] && grep -q "tests skipped" "$results/$name.results" ; then
+	if [ "$tests_exit" -eq 0 ] && [ "$output" == 'verbose' ] && grep -q "tests skipped" "$results/$name.results" ; then
 		echo "%         skipped"
-	elif [ $tests_exit -eq 0 ] && [ "$output" == 'verbose' ] && grep -q "(not applicable)" "$results/$name.results" ; then
+	elif [ "$tests_exit" -eq 0 ] && [ "$output" == 'verbose' ] && grep -q "(not applicable)" "$results/$name.results" ; then
 		echo "%         not applicable"
-	elif [ $tests_exit -eq 0 ] && [ -f "$results/$name.totals" ] && [ "$output" == 'verbose' ] ; then
+	elif [ "$tests_exit" -eq 0 ] && [ -f "$results/$name.totals" ] && [ "$output" == 'verbose' ] ; then
 		while read -r line ; do
 			echo -n "$mode_prefix"
 			echo -n "$(cut -f 3 <<< "$line")"
@@ -182,18 +183,18 @@ run_testset() {
 		done < <(grep '^object' "$results/$name.totals")
 		echo -n '%         clause coverage '
 		echo "$(grep "^coverage" "$results/$name.totals" | cut -f 2)"
-	elif [ $tests_exit -eq 5 ] ; then
+	elif [ "$tests_exit" -eq 5 ] ; then
 		if [ "$output" == 'verbose' ] ; then
 			echo "%         broken"
 		fi
 		ensure_format_report "$unit" "$(basename "$unit")" "Broken"
-	elif [ $tests_exit -eq 137 ] || [ $tests_exit -eq 124 ] ; then
+	elif [ "$tests_exit" -eq 137 ] || [ "$tests_exit" -eq 124 ] ; then
 		if [ "$output" == 'verbose' ] ; then
 			echo "%         timeout"
 		fi
 		echo "LOGTALK_TIMEOUT" >> "$results/$name.errors"
 		ensure_format_report "$unit" "$(basename "$unit")" "Timeout"
-	elif [ $tests_exit -ne 0 ] ; then
+	elif [ "$tests_exit" -ne 0 ] ; then
 		if [ "$output" == 'verbose' ] ; then
 			echo "%         crash"
 		fi
@@ -317,7 +318,7 @@ usage_help()
 	echo "     (valid values are none and xml)"
 	echo "  -l directory depth level to look for test sets (default is to recurse into all sub-directories)"
 	echo "     (level 1 means current directory only)"
-	echo "  -e exclude directories matching a regular expression (uses find command -E and -regex options)"
+	echo "  -e exclude directories matching a POSIX-extended regular expression"
 	echo "  -i integration script command-line options (no default)"
 	echo "  -g initialization goal (default is $initialization_goal)"
 	echo "  -r random generator starting seed (no default)"
@@ -362,37 +363,30 @@ if [ "$p_arg" == "" ] ; then
 	usage_help
 	exit 1
 elif [ "$p_arg" == "b" ] ; then
-	backend=b
 	prolog='B-Prolog'
 	logtalk=bplgt$extension
 	logtalk_call="$logtalk $i_arg -g"
 elif [ "$p_arg" == "ciao" ] ; then
-	backend=ciao
 	prolog='Ciao Prolog'
 	logtalk=ciaolgt$extension
 	logtalk_call="$logtalk $i_arg -e"
 elif [ "$p_arg" == "cx" ] ; then
-	backend=cx
 	prolog='CxProlog'
 	logtalk=cxlgt$extension
 	logtalk_call="$logtalk $i_arg --goal"
 elif [ "$p_arg" == "eclipse" ] ; then
-	backend=eclipse
 	prolog='ECLiPSe'
 	logtalk=eclipselgt$extension
 	logtalk_call="$logtalk $i_arg -e"
 elif [ "$p_arg" == "gnu" ] ; then
-	backend=gnu
 	prolog='GNU Prolog'
 	logtalk=gplgt$extension
 	logtalk_call="$logtalk $i_arg --query-goal"
 elif [ "$p_arg" == "ji" ] ; then
-	backend=ji
 	prolog='JIProlog'
 	logtalk=jiplgt$extension
 	logtalk_call="$logtalk $i_arg -n -g"
 elif [ "$p_arg" == "lvm" ] ; then
-	backend=lvm
 	prolog='LVM'
 	logtalk=lvmlgt$extension
 	logtalk_call="$logtalk $i_arg -g"
@@ -404,45 +398,37 @@ elif [ "$p_arg" == "lvm" ] ; then
 		*) dot=".";;
 	esac
 elif [ "$p_arg" == "scryer" ] ; then
-	backend=scryer
 	prolog='Scryer Prolog'
 	logtalk=scryerlgt$extension
 	logtalk_call="$logtalk $i_arg -g"
 elif [ "$p_arg" == "sicstus" ] ; then
-	backend=sicstus
 	prolog='SICStus Prolog'
 	logtalk=sicstuslgt$extension
 	logtalk_call="$logtalk $i_arg --goal"
 	dot="."
 elif [ "$p_arg" == "swi" ] ; then
-	backend=swi
 	prolog='SWI-Prolog'
 	logtalk=swilgt$extension
 	logtalk_call="$logtalk $i_arg -g"
 elif [ "$p_arg" == "swipack" ] ; then
-	backend=swipack
 	prolog='SWI-Prolog'
 	logtalk=swipl
 	logtalk_call="$logtalk $i_arg -g"
 elif [ "$p_arg" == "tau" ] ; then
-	backend=tau
 	prolog='Tau Prolog'
 	logtalk=taulgt$extension
 	logtalk_call="$logtalk $i_arg -g"
 	dot="."
 elif [ "$p_arg" == "trealla" ] ; then
-	backend=trealla
 	prolog='Trealla Prolog'
 	logtalk=tplgt$extension
 	logtalk_call="$logtalk $i_arg -g"
 elif [ "$p_arg" == "xsb" ] ; then
-	backend=xsb
 	prolog='XSB'
 	logtalk=xsblgt$extension
 	logtalk_call="$logtalk $i_arg -e"
 	dot="."
 elif [ "$p_arg" == "yap" ] ; then
-	backend=yap
 	prolog='YAP'
 	logtalk=yaplgt$extension
 	logtalk_call="$logtalk $i_arg -g"
@@ -596,15 +582,28 @@ if [ "$output" == 'verbose' ] ; then
 	grep -a "Prolog version:" "$results"/tester_versions.txt | $sed "s/Prolog/$prolog/"
 fi
 
+declare drivers
+declare testsets
 if [ "$exclude" == "" ] ; then
 	drivers="$(find "$base" $level -type f -name "$driver.lgt" -or -name "$driver.logtalk" | LC_ALL=C sort)"
 	testsets=$(find "$base" $level -type f -name "$driver.lgt" -or -name "$driver.logtalk" | wc -l | tr -d ' ')
-else
+	find_exit=$?
+elif [ "$(uname)" == "Darwin" ] ; then
 	drivers="$(find -E "$base" $level -type f -not -regex "$exclude" -name "$driver.lgt" -or -name "$driver.logtalk" | LC_ALL=C sort)"
 	testsets=$(find -E "$base" $level -type f -not -regex "$exclude" -name "$driver.lgt" -or -name "$driver.logtalk" | wc -l | tr -d ' ')
+	find_exit=$?
+else
+	drivers="$(find "$base" $level -type f -regextype posix-extended -not -regex "$exclude" -name "$driver.lgt" -or -name "$driver.logtalk" | LC_ALL=C sort)"
+	testsets=$(find "$base" $level -type f -regextype posix-extended -not -regex "$exclude" -name "$driver.lgt" -or -name "$driver.logtalk" | wc -l | tr -d ' ')
+	find_exit=$?
 fi
 
-if  [ $testsets -eq 0 ] ; then
+if [ "$find_exit" -gt 0 ] ; then
+	echo "%         find command returned code $find_exit"
+	exit 11
+fi
+
+if  [ "$testsets" -eq 0 ] ; then
 	echo "%"
 	echo "% 0 test sets: 0 completed, 0 skipped, 0 broken, 0 timedout, 0 crashed"
 	echo "% 0 tests: 0 skipped, 0 passed, 0 failed"
