@@ -4,10 +4,10 @@
 ## 
 ##   Logtalk script for updating the HTML library and tools SVG diagrams
 ## 
-##   Last updated on September 21, 2022
+##   Last updated on January 12, 2023
 ## 
 ##   This file is part of Logtalk <https://logtalk.org/>  
-##   Copyright 1998-2022 Paulo Moura <pmoura@logtalk.org>
+##   Copyright 1998-2023 Paulo Moura <pmoura@logtalk.org>
 ##   SPDX-License-Identifier: Apache-2.0
 ##   
 ##   Licensed under the Apache License, Version 2.0 (the "License");
@@ -75,7 +75,7 @@ set_goals() {
 }
 
 print_version() {
-	echo "$(basename "$0") 0.22"
+	echo "$(basename "$0") 0.23"
 	exit 0
 }
 
@@ -83,8 +83,8 @@ print_version() {
 usage_help()
 {
 	echo 
-	echo "This script updates the SVG diagrams of the core entities, the library,"
-	echo "the development tools, and the third-party contributions."
+	echo "This script updates the SVG diagrams of the core entities, library,"
+	echo "developer tools, ports, contributions, and optionally installed packs."
 	echo
 	echo "Usage:"
 	echo "  $(basename "$0") [-p prolog] [-i]"
@@ -178,6 +178,8 @@ $logtalk "$contributions_goal"
 $logtalk "$ports_goal"
 
 "$LOGTALKHOME/tools/diagrams/lgt2svg.sh"
+lgt2svg_exit=$?
+
 rm ./*.dot
 
-exit 0
+exit $lgt2svg_exit
